function delete(varargin)
% deletes objects and corresponding data from swplot figure
% 
% ### Syntax
% 
% `swplot.delete(objID)`
%
% `swplot.delete(hFigure,objID)`
% 
% ### Description
% 
% `swplot.delete(objID)` deletes objects and their data that corresponds to
% the given unique `objID` (integer number) on the active swplot figure.
%
% `swplot.delete(hFigure,objID)` deletes objects from the swplot figure
% corresponding to `hFigure` handle.
%  
% If `objID` equals to 0, all objects will be deleted from the swplot
% figure.
%  
% ### See Also
%
% [swplot.figure] \| [swplot.add]
%

% $Name: SpinW$ ($Version: 3.1$)
% $Author: S. Tóth and S. Ward$ ($Contact: admin@spinw.org, @spinw4 on Twitter$)
% $Revision: 1591$ ($Date: 25-Apr-2019$)
% $License: GNU GENERAL PUBLIC LICENSE$

if nargin == 1
    hFigure = swplot.activefigure;
    number  = varargin{1};
elseif nargin == 2
    hFigure = varargin{1};
    number  = varargin{2};
end

% get the objects
sObj = getappdata(hFigure,'objects');

if any(number==0)
    % select all objects to delete
    pIdx = 1:numel(sObj);
    number = 1:max([sObj(:).number]);
    % delete legend
    swplot.legend('off',hFigure)
    setappdata(hFigure,'legend',struct('handle',gobjects(0),'text',{''},...
        'type',[],'color',[],'name',{''}));
    
else
    % find objects with the given numbers
    pIdx = ismember([sObj(:).number],number);
end

% all handles to delete
handle = unique([sObj(pIdx).handle]);

% empty face patches if necessary
for ii = 1:numel(handle)
    hPatch = handle(ii);
    if isappdata(hPatch,'facenumber')
        fn = getappdata(hPatch,'facenumber');
        F  = get(hPatch,'Faces');
        V  = get(hPatch,'Vertices');
        C  = get(hPatch,'FaceVertexCData');
        A  = get(hPatch,'FaceVertexAlphaData');
        % delete faces and vertices
        fToDel = ismember(fn,number);
        
        if all(fToDel)
            delete(hPatch);
        elseif any(fToDel)
            vToDel = F(fToDel,:);
            F(fToDel,:) = [];
            C(fToDel,:) = [];
            A(fToDel,:) = [];
            V(vToDel(:),:) = [];
            % renumber the face indices change old values to new values
            newF = changem(F,1:size(V,1),unique(F(:)'));
            set(hPatch,'Faces',newF,'Vertices',V,'FaceVertexCData',C,'FaceVertexAlphaData',A);
            setappdata(hPatch,'facenumber',fn(~fToDel));
        end
    elseif isappdata(hPatch,'vertexnumber')
        vn = getappdata(hPatch,'vertexnumber');
        F  = get(hPatch,'Faces');
        V  = get(hPatch,'Vertices');
        C  = get(hPatch,'FaceVertexCData');
        A  = get(hPatch,'FaceVertexAlphaData');
        % delete faces and vertices
        vToDel = ismember(vn,number);
        if all(vToDel)
            delete(hPatch);
        elseif any(vToDel)
            fToDel = ismember(F(:,1),find(vToDel));
            F(fToDel,:) = [];
            C(vToDel,:) = [];
            A(vToDel,:) = [];
            V(vToDel,:) = [];
            % renumber the face indices change old values to new values
            newF = changem(F,1:size(V,1),unique(F(:)'));
            set(hPatch,'Faces',newF,'Vertices',V,'FaceVertexCData',C,'FaceVertexAlphaData',A);
            setappdata(hPatch,'vertexnumber',vn(~vToDel));
        end
    else
        delete(hPatch);
    end
end

setappdata(hFigure,'objects',sObj(~pIdx));

end